@@ -135,8 +135,8 @@ def export(ctx, file):
             scriptPath = os.path.abspath('.')
         sys.path.append(scriptPath)
         print(sys.path)
-        from exportdfnsjkdfnsdkjfnsdjkf import Correspondence
-        ex = Correspondence(ctx.obj)
+        from export import Export
+        ex = Export(ctx.obj)
         ex.exec()
     except Exception as e:
         print(e)
